@@ -6,7 +6,9 @@ package Group::Git::Bitbucket;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose;
+use Moo;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
@@ -15,7 +17,7 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Class;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 extends 'Group::Git';
 
@@ -63,7 +65,7 @@ Group::Git::Bitbucket - Adds reading all repositories you have access to on bitb
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Bitbucket version 0.4.3.
+This documentation refers to Group::Git::Bitbucket version 0.5.0.
 
 =head1 SYNOPSIS
 
