@@ -6,14 +6,16 @@ package Group::Git::Cmd::List;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose::Role;
+use Moo::Role;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 requires 'repos';
 requires 'verbose';
@@ -28,7 +30,6 @@ my $opt = Getopt::Alt->new(
 sub list {
     my ($self, $name) = @_;
     return unless -d $name;
-    warn "$name\n";
 
     return ' ';
 }
@@ -43,7 +44,7 @@ Group::Git::Cmd::List - Runs git status on a git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::List version 0.4.3.
+This documentation refers to Group::Git::Cmd::List version 0.5.0.
 
 
 =head1 SYNOPSIS
