@@ -6,21 +6,53 @@ package Group::Git::Cmd::Pull;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose::Role;
+use Moo::Role;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 requires 'repos';
 requires 'verbose';
 
 my $opt = Getopt::Alt->new(
     { help => __PACKAGE__, },
-    [ 'quiet|q!', ]
+    [
+        'quiet|q!',
+        'verbose|v',
+        #'recurse-submodules=s![=yes|on-demand|no',
+        'recurse-submodules=[yes|on-demand|no]',
+        'commit!',
+        'edit|e!',
+        'ff!',
+        'ff-only',
+        #'log=d!',
+        'log=d',
+        'stat|n!',
+        'squash!',
+        'strategy|s=s',
+        'strategy-option|X=s',
+        'verify-signatures!',
+        'summary!',
+        #'rebase|r=s![=false|true|preserve]',
+        'rebase|r=[false|true|preserve]',
+        'all',
+        'append|a',
+        'depth=i',
+        'unshallow',
+        'update-shallow',
+        'force|f',
+        'keep|k',
+        'no-tags',
+        'update-head-ok|u',
+        'upload-pack=s',
+        'progress',
+    ]
 );
 
 sub update_start { shift->pull_start($_[0], 'update') }
@@ -43,7 +75,13 @@ sub pull {
     }
     elsif ( -d $name ) {
         $dir = $name;
-        $cmd = join ' ', 'git', map { $self->shell_quote } $type, @ARGV;
+        my @args = map {
+                $opt->opt->{$_} eq '0'   ? "--no-$_"
+                : $opt->opt->{$_} eq '1' ? "--$_"
+                :                          "--$_=" . $opt->opt->{$_};
+            }
+            keys %{ $opt->opt };
+        $cmd = join ' ', 'git', map { $self->shell_quote } $type, @args, @ARGV;
     }
     else {
         $cmd = join ' ', 'git', 'clone', map { $self->shell_quote } $repo->git, $name;
@@ -70,7 +108,7 @@ Group::Git::Cmd::Pull - Pull latest version of all repositories or clone any tha
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Pull version 0.4.3.
+This documentation refers to Group::Git::Cmd::Pull version 0.5.0.
 
 
 =head1 SYNOPSIS
