@@ -6,14 +6,16 @@ package Group::Git::Cmd::TagList;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose::Role;
+use Moo::Role;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 requires 'repos';
 requires 'verbose';
@@ -64,7 +66,7 @@ Group::Git::Cmd::TagList - Runs git status on a git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::TagList version 0.4.3.
+This documentation refers to Group::Git::Cmd::TagList version 0.5.0.
 
 =head1 SYNOPSIS
 
