@@ -6,15 +6,18 @@ package Group::Git::Cmd::Watch;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose::Role;
+use Moo::Role;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 use YAML::Syck qw/LoadFile DumpFile/;
+use Types::Standard qw/Bool/;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 requires 'repos';
 requires 'verbose';
@@ -40,7 +43,7 @@ my $opt = Getopt::Alt->new(
 
 has watch_run => (
     is  => 'rw',
-    isa => 'Bool',
+    isa => Bool,
 );
 
 sub watch_start {
@@ -71,7 +74,7 @@ sub watch {
     {
         local $CWD = $name;
         my ($id, $out);
-        `git fetch`;
+        `git fetch --quiet`;
 
         if ($opt->opt->all) {
             ($out) = `git reflog --all`;
@@ -114,7 +117,7 @@ Group::Git::Cmd::Watch - Watch for changes in repositories and run a command
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Watch version 0.4.3.
+This documentation refers to Group::Git::Cmd::Watch version 0.5.0.
 
 
 =head1 SYNOPSIS
