@@ -6,14 +6,16 @@ package Group::Git::Gitosis;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose;
+use Moo;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
 use Path::Class;
 use File::chdir;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 extends 'Group::Git';
 
@@ -75,7 +77,7 @@ Group::Git::Gitosis - Adds reading all repositories you have access to on a gito
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Gitosis version 0.4.3.
+This documentation refers to Group::Git::Gitosis version 0.5.0.
 
 
 =head1 SYNOPSIS
