@@ -6,24 +6,28 @@ package Group::Git::Repo;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose;
+use Moo;
+use strict;
+use warnings;
 use version;
+use Types::Standard qw/Str/;
+use Type::Utils;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 extends 'Group::Git';
 
 has name => (
     is  => 'rw',
-    isa => 'Path::Class::Dir',
+    isa => class_type { class => 'Path::Class::Dir' },
 );
 has url => (
     is  => 'rw',
-    isa => 'Str',
+    isa => Str,
 );
 has git => (
     is  => 'rw',
-    isa => 'Str',
+    isa => Str,
 );
 
 1;
@@ -36,7 +40,7 @@ Group::Git::Repo - Git repository details object.
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Repo version 0.4.3.
+This documentation refers to Group::Git::Repo version 0.5.0.
 
 
 =head1 SYNOPSIS
