@@ -6,7 +6,9 @@ package Group::Git::Stash;
 # $Revision$, $HeadURL$, $Date$
 # $Revision$, $Source$, $Date$
 
-use Moose;
+use Moo;
+use strict;
+use warnings;
 use version;
 use Carp;
 use English qw/ -no_match_vars /;
@@ -15,7 +17,7 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Class;
 
-our $VERSION = version->new('0.4.3');
+our $VERSION = version->new('0.5.0');
 
 extends 'Group::Git';
 
@@ -79,7 +81,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.4.3.
+This documentation refers to Group::Git::Stash version 0.5.0.
 
 =head1 SYNOPSIS
 
